==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-pane-drag-over-event-args.js <==
import { PaneDragOverEventArgs as PaneDragOverEventArgs_internal } from "./PaneDragOverEventArgs";
var IgrPaneDragOverEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneDragOverEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrPaneDragOverEventArgs.prototype.createImplementation = function () {
        return new PaneDragOverEventArgs_internal();
    };
    Object.defineProperty(IgrPaneDragOverEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneDragOverEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneDragOverEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPaneDragOverEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrPaneDragOverEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneDragOverEventArgs;
}());
export { IgrPaneDragOverEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-pane-drag-over-event-args.js <==
import { IgrPaneDragOverEventArgsDetail } from "./igr-pane-drag-over-event-args-detail";
import { PaneDragOverEventArgs as PaneDragOverEventArgs_internal } from "./PaneDragOverEventArgs";
var IgrPaneDragOverEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneDragOverEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPaneDragOverEventArgs.prototype.createImplementation = function () {
        return new PaneDragOverEventArgs_internal();
    };
    Object.defineProperty(IgrPaneDragOverEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneDragOverEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneDragOverEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPaneDragOverEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPaneDragOverEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneDragOverEventArgs;
}());
export { IgrPaneDragOverEventArgs };
